import OL18
import numpy as np

"""
Functions to use:

    OL18.epsilon_general (mode='', keywords)
        provides accretion efficiency in the most general case
        using keyword arguments and a mode
        See OL18.py for keywords and further description

    OL18.eps_set (tau, qp, eta, hgas, alphaz)
        convenience function
"""



#python 2/3 issues
try:
    plotAnswer = raw_input('Would you like to plot the results (loads matplotlib) [y/N]: ')
except:
    plotAnswer = input('Would you like to plot the results (loads matplotlib) [y/N]: ')



eccarr = 10**( np.linspace(-4.3,-0.5,100) )

eps2dFig3 = OL18.epsilon_general (ep=eccarr, tau=1e-2, qp=3e-7, 
                                    eta=1e-3, Rp=2.4e-5, mode='2df')

print("""
We have executed the follwing commands

# the 2D efficiency of figure 3 of Paper I
$ eps2dFig3 = OL18.epsilon_general (ep=eccarr, tau=1e-2, qp=3e-7,
                                    eta=1e-3, Rp=2.4e-5, mode='2df')

# the 3D efficiency assuming a turbulence alpha of 1e-4
$ epsFig3 = OL18.epsilon_general (ep=eccarr, tau=1e-2, qp=3e-7, 
                                    eta=1e-3, hgas=0.03, alphaz=1e-4, Rp=2.4e-5)
""")



#this is when we would include 3d effects as well!
#with some modest turbulence. The alphaz parameter must be included

epsFig3 = OL18.epsilon_general (ep=eccarr, tau=1e-2, qp=3e-7, 
                                    eta=1e-3, hgas=0.03, alphaz=1e-4, Rp=2.4e-5)
if plotAnswer=='y' or plotAnswer=='Y':
    import pylab as pl
    fg = pl.figure()
    ax = fg.add_subplot(111)
    ax.loglog(eccarr, eps2dFig3, 'k-')
    ax.loglog(eccarr, epsFig3, 'r-')
    ax.set_ylim(0.01, 0.4)
    ax.set_xlim(5e-5, 0.25)
    ax.legend(['2D, Fig 3 of Paper I', '3D w/ alpha=1e-4 (not shown in Papers)'])
    ax.set_xlabel('eccentricity')
    ax.set_ylabel('efficiency')
    fg.savefig('LiuOrmel2018figure3.pdf')

#stopping time array
tauarr = 10**( np.linspace(-3.0,0.7,100) )

#this produces the curves of Figure 4, Paper II
#the 2dfset keyword indicates:
# - only settling regime 'set'; no ballistic encounters
# - in 2d limit
# - including fset correction factors

#the black solid line (2D, laminar)
eps2d = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, mode='2dfset')


#the purple dotted lines (for alphaz=1e-3)
eps3d = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                alphaz=1e-3, mode='3dset')


#the red solid line (settling, mix of 2d and 3d, including fset factor)
#Note the nvec keyword, b/c in the paper turbulence is only occures in the z-direction
#the default is isotropic turbulence, where the planar rms-velocity components 
#are assumed to have the same value as the vertical
epsset = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                alphaz=1e-3, nvec=(0,0,1), mode='setf')

#We also provide a convenience funtion for the settling epsilon without
#accounting for fset reduction factor
epsset2 = OL18.eps_set (tauarr, 3e-7, 1e-3, 0.03, 1e-3)

#all effects (isotropic turbulence, ballistic+settling in 3D; not treated in Paper II)
#numbers are virtually the same, however
epstot = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                Rp=2.4e-5, alphaz=1e-3)


print("""
============
Second Figure. We have executed the follwing commands:

# the 2D limit (black line of figure 4 of Paper II)
$ eps2d = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, mode='2dfset')

# the 3D limit for alpha_z=1e-3 (dotted line)
$ eps3d = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                alphaz=1e-3, mode='3dset')

# the 3D results of the paper
$ epsset = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                alphaz=1e-3, nvec=(0,0,1), mode='setf')

# a convenience function, which disregards the fset correction
$ epsset2 = OL18.eps_set (tauarr, 3e-7, 1e-3, 0.03, 1e-3)

# the most general solution, assuming isotropic turbulence
$ epstot = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                Rp=2.4e-5, alphaz=1e-3)
""")

#python 2/3 issues
if plotAnswer=='y' or plotAnswer=='Y':
    fg = pl.figure(figsize=(4,5))
    ax = fg.add_subplot(111)

    ax.loglog(tauarr, eps2d, 'k-')
    ax.loglog(tauarr, eps3d, 'm:')
    ax.loglog(tauarr, epsset, 'm-')
    ax.loglog(tauarr, epsset2, 'm--')
    ax.loglog(tauarr, epstot, 'm-.')

    ax.legend(['2D limit (paper)', '3D limit', 'Paper', 'no fset', 'isotropic turb.'])

    ax.set_xlim(8e-4, 11.)
    ax.set_ylim(2e-3, 0.22)
    ax.set_xlabel('Stopping time tau')
    ax.set_ylabel('Efficiency')
    fg.savefig('OrmelLiu2018figure4.pdf')


#A curve from Fig. 7, where we treat inclination
ipList = [0., 1e-3, 2e-3, 5e-3, 1e-2, 2e-2, 5e-2, 0.1]

rgbList = [(0,0,0), (0,0,0.1), (0,0,0.28), (0,0,0.5), (0,0,0.75), (0,0,1), (0.25,0.25,1), (0.5,0.5, 1)]


Nip = len(ipList)

for k in range(Nip):
    epssetinc = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                                alphaz=1e-4, ip=ipList[k], nvec=(0,0,1), mode='setf')

    if plotAnswer=='y' or plotAnswer=='Y':
        if k==0:
            fg = pl.figure(figsize=(4,5))
            ax = fg.add_subplot(111)

        ax.loglog(tauarr, epssetinc, '-', c=rgbList[k])
        if k==Nip-1:
            ax.set_xlim(6e-4, 2.)
            ax.set_ylim(2e-5, 0.2)

            ax.set_ylabel('Efficiency')
            ax.set_xlabel('Stopping time')
            fg.savefig('OrmelLiu2018figure7.pdf')
            pl.close(fg)

print("""
============
Third Figure. We have executed the follwing commands:

$ epssetinc = OL18.epsilon_general (tau=tauarr, qp=3e-7, eta=1e-3, hgas=0.03, 
                   alphaz=1e-4, ip=ipList[k], nvec=(0,0,1), mode='setf')

for all inclination values in ipList. This reproduces 
the middle panel of figure 7 in Ormel & Liu (2018)

(c) Chris Ormel and Beibei Liu (2018)
""")
